Queue Staging Tab
-----------------

.. card::

    .. image:: ../../_static/screenshots/queue_staging.png
        :alt: Queue Staging

Queue Staging is a holding area for plans that are not ready to be executed. Plans can be added to staging by clicking
``Add to Staging`` rather than ``Add to Queue`` in the Plan Widgets or Plan Editor tabs. Staged plans can be
moved, edited, duplicated, and deleted in exactly the same way as plans in the Queue.

.. Attention::
    Plans in Queue Staging will not be executed unless they are moved to the Queue! 
    Do not forget to move plans to the Queue!

When to use Queue Staging
~~~~~~~~~~~~~~~~~~~~~~~~~~

Queue Staging is useful for:

- Making sure that plans do not run until the entire sequence is complete.
- Editing plans that are not ready to be executed.
- Saving a sequence of plans for later execution.
- Assembling a whole sequence that can be repeatedly added to the Queue.
- Adding plans to the Meta Plan Widget (advanced).

